==> datasets-2.3.1.tar.gz: datasets-2.3.1/datasets/universal_dependencies/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- crowdsourced
languages:
- 'no'
- af
- aii
- ajp
- akk
- am
- apu
- aqz
- ar
- be
- bg
- bho
- bm
- br
- bxr
- ca
- ckt
- cop
- cs
- cu
- cy
- da
- de
- el
- en
- es
- et
- eu
- fa
- fi
- fo
- fr
- fro
- ga
- gd
- gl
- got
- grc
- gsw
- gun
- gv
- he
- hi
- hr
- hsb
- hu
- hy
- id
- is
- it
- ja
- kfm
- kk
- kmr
- ko
- koi
- kpv
- krl
- la
- lt
- lv
- lzh
- mdf
- mr
- mt
- myu
- myv
- nl
- nyq
- olo
- orv
- otk
- pcm
- pl
- pt
- qhe
- qtd
- ro
- ru
- sa
- sk
- sl
- sme
- sms
- soj
- sq
- sr
- sv
- swl
- ta
- te
- th
- tl
- tpn
- tr
- ug
- uk
- ur
- vi
- wbp
- wo
- yo
- yue
- zh
licenses:
- unknown
multilinguality:
- multilingual
size_categories:
- 1K<n<10K
source_datasets:
- original
task_categories:
- other
task_ids:
- constituency-parsing
- dependency-parsing
paperswithcode_id: universal-dependencies
pretty_name: Universal Dependencies Treebank
configs:
- af_afribooms
- aii_as
- ajp_madar
- akk_pisandub
- akk_riao
- am_att
- apu_ufpa
- aqz_tudet
- ar_nyuad
- ar_padt
- ar_pud
- be_hse
- bg_btb
- bho_bhtb
- bm_crb
- br_keb
- bxr_bdt
- ca_ancora
- ckt_hse
- cop_scriptorium
- cs_cac
- cs_cltt
- cs_fictree
- cs_pdt
- cs_pud
- cu_proiel
- cy_ccg
- da_ddt
- de_gsd
- de_hdt
- de_lit
- de_pud
- el_gdt
- en_esl
- en_ewt
- en_gum
- en_gumreddit
- en_lines
- en_partut
- en_pronouns
- en_pud
- es_ancora
- es_gsd
- es_pud
- et_edt
- et_ewt
- eu_bdt
- fa_perdt
- fa_seraji
- fi_ftb
- fi_ood
- fi_pud
- fi_tdt
- fo_farpahc
- fo_oft
- fr_fqb
- fr_ftb
- fr_gsd
- fr_partut
- fr_pud
- fr_sequoia
- fr_spoken
- fro_srcmf
- ga_idt
- gd_arcosg
- gl_ctg
- gl_treegal
- got_proiel
- grc_perseus
- grc_proiel
- gsw_uzh
- gun_dooley
- gun_thomas
- gv_cadhan
- he_htb
- hi_hdtb
- hi_pud
- hr_set
- hsb_ufal
- hu_szeged
- hy_armtdp
- id_csui
- id_gsd
- id_pud
- is_icepahc
- is_pud
- it_isdt
- it_partut
- it_postwita
- it_pud
- it_twittiro
- it_vit
- ja_bccwj
- ja_gsd
- ja_modern
- ja_pud
- kfm_aha
- kk_ktb
- kmr_mg
- ko_gsd
- ko_kaist
- ko_pud
- koi_uh
- kpv_ikdp
- kpv_lattice
- krl_kkpp
- la_ittb
- la_llct
- la_perseus
- la_proiel
- lt_alksnis
- lt_hse
- lv_lvtb
- lzh_kyoto
- mdf_jr
- mr_ufal
- mt_mudt
- myu_tudet
- myv_jr
- nl_alpino
- nl_lassysmall
- no_bokmaal
- no_nynorsk
- no_nynorsklia
- nyq_aha
- olo_kkpp
- orv_rnc
- orv_torot
- otk_tonqq
- pcm_nsc
- pl_lfg
- pl_pdb
- pl_pud
- pt_bosque
- pt_gsd
- pt_pud
- qhe_hiencs
- qtd_sagt
- ro_nonstandard
- ro_rrt
- ro_simonero
- ru_gsd
- ru_pud
- ru_syntagrus
- ru_taiga
- sa_ufal
- sa_vedic
- sk_snk
- sl_ssj
- sl_sst
- sme_giella
- sms_giellagas
- soj_aha
- sq_tsa
- sr_set
- sv_lines
- sv_pud
- sv_talbanken
- swl_sslc
- ta_mwtt
- ta_ttb
- te_mtg
- th_pud
- tl_trg
- tl_ugnayan
- tpn_tudet
- tr_boun
- tr_gb
- tr_imst
- tr_pud
- ug_udt
- uk_iu
- ur_udtb
- vi_vtb
- wbp_ufal
- wo_wtb
- yo_ytb
- yue_hk
- zh_cfl
- zh_gsd
- zh_gsdsimp
- zh_hk
- zh_pud
---

# Dataset Card for Universal Dependencies Treebank

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** [Universal Dependencies](https://universaldependencies.org/)
- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

[More Information Needed]

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]
### Contributions

Thanks to [@patrickvonplaten](https://github.com/patrickvonplaten), [@jplu](https://github.com/jplu) for adding this dataset.

==> datasets-2.5.2.tar.gz: datasets-2.5.2/datasets/universal_dependencies/README.md <==
---
annotations_creators:
- expert-generated
language_creators:
- crowdsourced
language:
- af
- aii
- ajp
- akk
- am
- apu
- aqz
- ar
- be
- bg
- bho
- bm
- br
- bxr
- ca
- ckt
- cop
- cs
- cu
- cy
- da
- de
- el
- en
- es
- et
- eu
- fa
- fi
- fo
- fr
- fro
- ga
- gd
- gl
- got
- grc
- gsw
- gun
- gv
- he
- hi
- hr
- hsb
- hu
- hy
- id
- is
- it
- ja
- kfm
- kk
- kmr
- ko
- koi
- kpv
- krl
- la
- lt
- lv
- lzh
- mdf
- mr
- mt
- myu
- myv
- nl
- 'no'
- nyq
- olo
- orv
- otk
- pcm
- pl
- pt
- ro
- ru
- sa
- sk
- sl
- sme
- sms
- soj
- sq
- sr
- sv
- swl
- ta
- te
- th
- tl
- tpn
- tr
- ug
- uk
- ur
- vi
- wbp
- wo
- yo
- yue
- zh
license:
- unknown
multilinguality:
- multilingual
size_categories:
- 1K<n<10K
source_datasets:
- original
task_categories:
- token-classification
task_ids:
- parsing
- token-classification-other-constituency-parsing
- token-classification-other-dependency-parsing
paperswithcode_id: universal-dependencies
pretty_name: Universal Dependencies Treebank
configs:
- af_afribooms
- aii_as
- ajp_madar
- akk_pisandub
- akk_riao
- am_att
- apu_ufpa
- aqz_tudet
- ar_nyuad
- ar_padt
- ar_pud
- be_hse
- bg_btb
- bho_bhtb
- bm_crb
- br_keb
- bxr_bdt
- ca_ancora
- ckt_hse
- cop_scriptorium
- cs_cac
- cs_cltt
- cs_fictree
- cs_pdt
- cs_pud
- cu_proiel
- cy_ccg
- da_ddt
- de_gsd
- de_hdt
- de_lit
- de_pud
- el_gdt
- en_esl
- en_ewt
- en_gum
- en_gumreddit
- en_lines
- en_partut
- en_pronouns
- en_pud
- es_ancora
- es_gsd
- es_pud
- et_edt
- et_ewt
- eu_bdt
- fa_perdt
- fa_seraji
- fi_ftb
- fi_ood
- fi_pud
- fi_tdt
- fo_farpahc
- fo_oft
- fr_fqb
- fr_ftb
- fr_gsd
- fr_partut
- fr_pud
- fr_sequoia
- fr_spoken
- fro_srcmf
- ga_idt
- gd_arcosg
- gl_ctg
- gl_treegal
- got_proiel
- grc_perseus
- grc_proiel
- gsw_uzh
- gun_dooley
- gun_thomas
- gv_cadhan
- he_htb
- hi_hdtb
- hi_pud
- hr_set
- hsb_ufal
- hu_szeged
- hy_armtdp
- id_csui
- id_gsd
- id_pud
- is_icepahc
- is_pud
- it_isdt
- it_partut
- it_postwita
- it_pud
- it_twittiro
- it_vit
- ja_bccwj
- ja_gsd
- ja_modern
- ja_pud
- kfm_aha
- kk_ktb
- kmr_mg
- ko_gsd
- ko_kaist
- ko_pud
- koi_uh
- kpv_ikdp
- kpv_lattice
- krl_kkpp
- la_ittb
- la_llct
- la_perseus
- la_proiel
- lt_alksnis
- lt_hse
- lv_lvtb
- lzh_kyoto
- mdf_jr
- mr_ufal
- mt_mudt
- myu_tudet
- myv_jr
- nl_alpino
- nl_lassysmall
- no_bokmaal
- no_nynorsk
- no_nynorsklia
- nyq_aha
- olo_kkpp
- orv_rnc
- orv_torot
- otk_tonqq
- pcm_nsc
- pl_lfg
- pl_pdb
- pl_pud
- pt_bosque
- pt_gsd
- pt_pud
- qhe_hiencs
- qtd_sagt
- ro_nonstandard
- ro_rrt
- ro_simonero
- ru_gsd
- ru_pud
- ru_syntagrus
- ru_taiga
- sa_ufal
- sa_vedic
- sk_snk
- sl_ssj
- sl_sst
- sme_giella
- sms_giellagas
- soj_aha
- sq_tsa
- sr_set
- sv_lines
- sv_pud
- sv_talbanken
- swl_sslc
- ta_mwtt
- ta_ttb
- te_mtg
- th_pud
- tl_trg
- tl_ugnayan
- tpn_tudet
- tr_boun
- tr_gb
- tr_imst
- tr_pud
- ug_udt
- uk_iu
- ur_udtb
- vi_vtb
- wbp_ufal
- wo_wtb
- yo_ytb
- yue_hk
- zh_cfl
- zh_gsd
- zh_gsdsimp
- zh_hk
- zh_pud
---

# Dataset Card for Universal Dependencies Treebank

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** [Universal Dependencies](https://universaldependencies.org/)
- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

[More Information Needed]

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]
### Contributions

Thanks to [@patrickvonplaten](https://github.com/patrickvonplaten), [@jplu](https://github.com/jplu) for adding this dataset.
